import { Disclosure as FoundationDisclosure } from '@microsoft/fast-foundation';
import { disclosureStyles as styles } from './disclosure.styles.js';
/**
 * Types of anchor appearance.
 * @public
 */
export type DisclosureAppearance = 'accent' | 'lightweight';
/**
 * @internal
 */
export declare class Disclosure extends FoundationDisclosure {
    /**
     * Disclosure default height
     */
    private height;
    /**
     * Disclosure height after it's expanded
     */
    private totalHeight;
    connectedCallback(): void;
    /**
     * The appearance the anchor should have.
     *
     * @public
     * @remarks
     * HTML Attribute: appearance
     */
    appearance?: DisclosureAppearance;
    appearanceChanged(oldValue: DisclosureAppearance, newValue: DisclosureAppearance): void;
    /**
     * Set disclosure height while transitioning
     * @override
     */
    protected onToggle(): void;
    /**
     * Calculate disclosure height before and after expanded
     * @override
     */
    protected setup(): void;
    get disclosureHeight(): number;
}
/**
 * A function that returns a {@link @microsoft/fast-foundation#Disclosure} registration for configuring the component with a DesignSystem.
 * Implements {@link @microsoft/fast-foundation#disclosureTemplate}
 *
 *
 * @public
 * @remarks
 * Generates HTML Element: `<jp-Disclosure>`
 *
 */
export declare const jpDisclosure: (overrideDefinition?: import("@microsoft/fast-foundation").OverrideFoundationElementDefinition<{
    baseName: string;
    baseClass: typeof FoundationDisclosure;
    template: import("@microsoft/fast-foundation").FoundationElementTemplate<import("@microsoft/fast-element").ViewTemplate<FoundationDisclosure, any>, import("@microsoft/fast-foundation").FoundationElementDefinition>;
    styles: import("@microsoft/fast-foundation").FoundationElementTemplate<import("@microsoft/fast-element").ElementStyles>;
}> | undefined) => import("@microsoft/fast-foundation").FoundationElementRegistry<{
    baseName: string;
    baseClass: typeof FoundationDisclosure;
    template: import("@microsoft/fast-foundation").FoundationElementTemplate<import("@microsoft/fast-element").ViewTemplate<FoundationDisclosure, any>, import("@microsoft/fast-foundation").FoundationElementDefinition>;
    styles: import("@microsoft/fast-foundation").FoundationElementTemplate<import("@microsoft/fast-element").ElementStyles>;
}, typeof Disclosure>;
export { styles as disclosureStyles };
