import type { ComboboxOptions } from '@microsoft/fast-foundation';
import { Combobox as FoundationCombobox } from '@microsoft/fast-foundation';
import { comboboxStyles as styles } from './combobox.styles.js';
/**
 * Base class for Combobox.
 * @public
 */
export declare class Combobox extends FoundationCombobox {
    /**
     * Whether the combobox has a compact layout or not.
     *
     * @public
     * @remarks
     * HTML Attribute: minimal
     */
    autoWidth: boolean;
    /**
     * Whether the combobox has a compact layout or not.
     *
     * @public
     * @remarks
     * HTML Attribute: minimal
     */
    minimal: boolean;
    /**
     * The connected callback for this FASTElement.
     *
     * @override
     *
     * @internal
     */
    connectedCallback(): void;
    /**
     * Synchronize the form-associated proxy and updates the value property of the element.
     *
     * @param prev - the previous collection of slotted option elements
     * @param next - the next collection of slotted option elements
     *
     * @internal
     */
    slottedOptionsChanged(prev: Element[] | undefined, next: Element[]): void;
    /**
     * (Un-)set the width when the autoWidth property changes.
     *
     * @param prev - the previous autoWidth value
     * @param next - the current autoWidth value
     */
    protected autoWidthChanged(prev: boolean | undefined, next: boolean): void;
    /**
     * Compute the listbox width to set the one of the input.
     */
    protected setAutoWidth(): void;
    /**
     * An internal stylesheet to hold calculated CSS custom properties.
     *
     * @internal
     */
    private computedStylesheet?;
    /**
     * @internal
     */
    protected maxHeightChanged(prev: number | undefined, next: number): void;
    /**
     * Updates an internal stylesheet with calculated CSS custom properties.
     *
     * @internal
     */
    protected updateComputedStylesheet(): void;
}
/**
 * A function that returns a {@link @microsoft/fast-foundation#Combobox} registration for configuring the component with a DesignSystem.
 * Implements {@link @microsoft/fast-foundation#comboboxTemplate}
 *
 * @public
 * @remarks
 * Generates HTML Element: `<jp-combobox>`
 *
 */
export declare const jpCombobox: (overrideDefinition?: import("@microsoft/fast-foundation").OverrideFoundationElementDefinition<ComboboxOptions> | undefined) => import("@microsoft/fast-foundation").FoundationElementRegistry<ComboboxOptions, import("@microsoft/fast-element").Constructable<import("@microsoft/fast-foundation").FoundationElement>>;
export { styles as comboboxStyles };
