import { ITranslator } from '@jupyterlab/translation';
import { VDomModel, VDomRenderer } from '@jupyterlab/ui-components';
import { CodeEditor } from './editor';
/**
 * A widget implementing a line/column status item.
 */
export declare class LineCol extends VDomRenderer<LineCol.Model> {
    /**
     * Construct a new LineCol status item.
     */
    constructor(translator?: ITranslator);
    /**
     * Render the status item.
     */
    render(): JSX.Element | null;
    /**
     * A click handler for the widget.
     */
    private _handleClick;
    /**
     * Handle submission for the widget.
     */
    private _handleSubmit;
    protected translator: ITranslator;
    private _popup;
}
/**
 * A namespace for LineCol statics.
 */
export declare namespace LineCol {
    /**
     * A VDom model for a status item tracking the line/column of an editor.
     */
    class Model extends VDomModel {
        /**
         * The current editor of the model.
         */
        get editor(): CodeEditor.IEditor | null;
        set editor(editor: CodeEditor.IEditor | null);
        /**
         * The current line of the model.
         */
        get line(): number;
        /**
         * The current column of the model.
         */
        get column(): number;
        /**
         * React to a change in the cursors of the current editor.
         */
        private _onSelectionChanged;
        private _getAllState;
        private _triggerChange;
        private _line;
        private _column;
        private _editor;
    }
}
