/**
 * A policy for use with the standard trustedTypes platform API.
 * @public
 */
export declare type TrustedTypesPolicy = {
    /**
     * Creates trusted HTML.
     * @param html - The HTML to clear as trustworthy.
     */
    createHTML(html: string): string;
};
/**
 * Enables working with trusted types.
 * @public
 */
export declare type TrustedTypes = {
    /**
     * Creates a trusted types policy.
     * @param name - The policy name.
     * @param rules - The policy rules implementation.
     */
    createPolicy(name: string, rules: TrustedTypesPolicy): TrustedTypesPolicy;
};
/**
 * The FAST global.
 * @internal
 */
export interface FASTGlobal {
    /**
     * The list of loaded versions.
     */
    readonly versions: string[];
    /**
     * Gets a kernel value.
     * @param id - The id to get the value for.
     * @param initialize - Creates the initial value for the id if not already existing.
     */
    getById<T>(id: string | number): T | null;
    getById<T>(id: string | number, initialize: () => T): T;
}
/**
 * The platform global type.
 * @public
 */
export declare type Global = typeof globalThis & {
    /**
     * Enables working with trusted types.
     */
    trustedTypes: TrustedTypes;
    /**
     * The FAST global.
     * @internal
     */
    readonly FAST: FASTGlobal;
};
/**
 * A reference to globalThis, with support
 * for browsers that don't yet support the spec.
 * @public
 */
export declare const $global: Global;
/**
 * The FAST global.
 * @internal
 */
export declare const FAST: FASTGlobal;
/**
 * Core services shared across FAST instances.
 * @internal
 */
export declare const enum KernelServiceId {
    updateQueue = 1,
    observable = 2,
    contextEvent = 3,
    elementRegistry = 4
}
/**
 * A readonly, empty array.
 * @remarks
 * Typically returned by APIs that return arrays when there are
 * no actual items to return.
 * @internal
 */
export declare const emptyArray: readonly never[];
/**
 * Creates a function capable of locating metadata associated with a type.
 * @returns A metadata locator function.
 * @internal
 */
export declare function createMetadataLocator<TMetadata>(): (target: {}) => TMetadata[];
