import type ReactModule from "react";
import { Constructable } from "@microsoft/fast-element";
import { DesignSystem, FoundationElementDefinition, FoundationElementRegistry, Registry } from "@microsoft/fast-foundation";
/**
 * Event signatures for a React wrapper.
 * @public
 */
export declare type ReactEvents<T> = {
    [P in keyof T]?: (e: Event) => unknown;
};
/**
 * Maps React event names to DOM event types for special handling.
 * @public
 */
export declare type ReactEventMap<T> = {
    [P in keyof T]: string;
};
/**
 * Optional configuration for the React wrapper.
 * @public
 */
export declare type ReactWrapperConfig<TEvents> = {
    /**
     * The tag that the React component will generate.
     */
    name?: string;
    /**
     * A mapping of React event name to DOM event type to be handled
     * by attaching event listeners to the underlying web component.
     * @remarks
     * Typically only needed for non-FAST web components.
     */
    events?: ReactEventMap<TEvents>;
    /**
     * A list of properties to be handled directly by the wrapper.
     * @remarks
     * Typically only needed for vanilla web components.
     */
    properties?: string[];
};
/**
 * The props used by a ReactWrapper.
 * @public
 */
export declare type ReactWrapperProps<TElement extends HTMLElement, TEvents> = ReactModule.PropsWithChildren<ReactModule.PropsWithRef<Partial<Omit<TElement, "children" | "style">> & ReactEvents<TEvents> & ReactModule.HTMLAttributes<HTMLElement>> & {
    style?: ReactModule.CSSProperties;
}>;
/**
 * A React component that wraps a Web Component.
 * @public
 */
export declare type ReactWrapper<TElement extends HTMLElement, TEvents> = Constructable<ReactModule.Component<ReactWrapperProps<TElement, TEvents>>>;
/**
 * Extracts the element type from a FoundationElementRegistry
 * @public
 */
export declare type FoundationElementRegistryElement<TRegistry> = TRegistry extends FoundationElementRegistry<FoundationElementDefinition, infer TElement> ? TElement extends typeof HTMLElement ? InstanceType<TElement> : any : any;
/**
 * @param React - The React module, typically imported from the `react` npm
 * package
 * @param designSystem - A design system to register the components with.
 * @public
 */
export declare function provideReactWrapper(React: any, designSystem?: DesignSystem): {
    wrap: {
        <TRegistry extends FoundationElementRegistry<FoundationElementDefinition, any>, TEvents>(registry: TRegistry, config?: ReactWrapperConfig<TEvents> | undefined): ReactWrapper<FoundationElementRegistryElement<TRegistry>, TEvents>;
        <TElement extends HTMLElement, TEvents_1>(type: Constructable<TElement>, config?: ReactWrapperConfig<TEvents_1> | undefined): ReactWrapper<TElement, TEvents_1>;
    };
    registry: Registry;
};
